sanskrit\_text package
======================

Submodules
----------

sanskrit\_text.cli module
-------------------------

.. automodule:: sanskrit_text.cli
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: sanskrit_text
   :members:
   :undoc-members:
   :show-inheritance:
